@@ -55,8 +55,8 @@
 #define __NR_sethostname	74
 #define __NR_setrlimit	75
 #define __NR_getrusage	77
-#define __NR_gettimeofday	78
-#define __NR_settimeofday	79
+#define __NR_gettimeofday_time32	78
+#define __NR_settimeofday_time32	79
 #define __NR_getgroups	80
 #define __NR_setgroups	81
 #define __NR_symlink	83
@@ -211,14 +211,14 @@
 #define __NR_remap_file_pages	253
 #define __NR_set_tid_address	256
 #define __NR_timer_create	257
-#define __NR_timer_settime	258
-#define __NR_timer_gettime	259
+#define __NR_timer_settime32	258
+#define __NR_timer_gettime32	259
 #define __NR_timer_getoverrun	260
 #define __NR_timer_delete	261
-#define __NR_clock_settime	262
-#define __NR_clock_gettime	263
-#define __NR_clock_getres	264
-#define __NR_clock_nanosleep	265
+#define __NR_clock_settime32	262
+#define __NR_clock_gettime32	263
+#define __NR_clock_getres_time32	264
+#define __NR_clock_nanosleep_time32	265
 #define __NR_statfs64	266
 #define __NR_fstatfs64	267
 #define __NR_tgkill	268
@@ -308,8 +308,8 @@
 #define __NR_timerfd_create	350
 #define __NR_eventfd	351
 #define __NR_fallocate	352
-#define __NR_timerfd_settime	353
-#define __NR_timerfd_gettime	354
+#define __NR_timerfd_settime32	353
+#define __NR_timerfd_gettime32	354
 #define __NR_signalfd4	355
 #define __NR_eventfd2	356
 #define __NR_epoll_create1	357
@@ -354,6 +354,41 @@
 #define __NR_pkey_free	396
 #define __NR_statx	397
 #define __NR_rseq	398
+#define __NR_io_pgetevents	399
+#define __NR_migrate_pages	400
+#define __NR_kexec_file_load	401
+#define __NR_clock_gettime64	403
+#define __NR_clock_settime64	404
+#define __NR_clock_adjtime64	405
+#define __NR_clock_getres_time64	406
+#define __NR_clock_nanosleep_time64	407
+#define __NR_timer_gettime64	408
+#define __NR_timer_settime64	409
+#define __NR_timerfd_gettime64	410
+#define __NR_timerfd_settime64	411
+#define __NR_utimensat_time64	412
+#define __NR_pselect6_time64	413
+#define __NR_ppoll_time64	414
+#define __NR_io_pgetevents_time64	416
+#define __NR_recvmmsg_time64	417
+#define __NR_mq_timedsend_time64	418
+#define __NR_mq_timedreceive_time64	419
+#define __NR_semtimedop_time64	420
+#define __NR_rt_sigtimedwait_time64	421
+#define __NR_futex_time64	422
+#define __NR_sched_rr_get_interval_time64	423
+#define __NR_pidfd_send_signal	424
+#define __NR_io_uring_setup	425
+#define __NR_io_uring_enter	426
+#define __NR_io_uring_register	427
+#define __NR_open_tree		428
+#define __NR_move_mount		429
+#define __NR_fsopen		430
+#define __NR_fsconfig		431
+#define __NR_fsmount		432
+#define __NR_fspick		433
+#define __NR_pidfd_open		434
+#define __NR_clone3		435
 
 #define __ARM_NR_breakpoint	0x0f0001
 #define __ARM_NR_cacheflush	0x0f0002
@@ -419,8 +454,8 @@
 #define SYS_sethostname	74
 #define SYS_setrlimit	75
 #define SYS_getrusage	77
-#define SYS_gettimeofday	78
-#define SYS_settimeofday	79
+#define SYS_gettimeofday_time32	78
+#define SYS_settimeofday_time32	79
 #define SYS_getgroups	80
 #define SYS_setgroups	81
 #define SYS_symlink	83
@@ -575,14 +610,14 @@
 #define SYS_remap_file_pages	253
 #define SYS_set_tid_address	256
 #define SYS_timer_create	257
-#define SYS_timer_settime	258
-#define SYS_timer_gettime	259
+#define SYS_timer_settime32	258
+#define SYS_timer_gettime32	259
 #define SYS_timer_getoverrun	260
 #define SYS_timer_delete	261
-#define SYS_clock_settime	262
-#define SYS_clock_gettime	263
-#define SYS_clock_getres	264
-#define SYS_clock_nanosleep	265
+#define SYS_clock_settime32	262
+#define SYS_clock_gettime32	263
+#define SYS_clock_getres_time32	264
+#define SYS_clock_nanosleep_time32	265
 #define SYS_statfs64	266
 #define SYS_fstatfs64	267
 #define SYS_tgkill	268
@@ -672,8 +707,8 @@
 #define SYS_timerfd_create	350
 #define SYS_eventfd	351
 #define SYS_fallocate	352
-#define SYS_timerfd_settime	353
-#define SYS_timerfd_gettime	354
+#define SYS_timerfd_settime32	353
+#define SYS_timerfd_gettime32	354
 #define SYS_signalfd4	355
 #define SYS_eventfd2	356
 #define SYS_epoll_create1	357
@@ -718,3 +753,38 @@
 #define SYS_pkey_free	396
 #define SYS_statx	397
 #define SYS_rseq	398
+#define SYS_io_pgetevents	399
+#define SYS_migrate_pages	400
+#define SYS_kexec_file_load	401
+#define SYS_clock_gettime64	403
+#define SYS_clock_settime64	404
+#define SYS_clock_adjtime64	405
+#define SYS_clock_getres_time64	406
+#define SYS_clock_nanosleep_time64	407
+#define SYS_timer_gettime64	408
+#define SYS_timer_settime64	409
+#define SYS_timerfd_gettime64	410
+#define SYS_timerfd_settime64	411
+#define SYS_utimensat_time64	412
+#define SYS_pselect6_time64	413
+#define SYS_ppoll_time64	414
+#define SYS_io_pgetevents_time64	416
+#define SYS_recvmmsg_time64	417
+#define SYS_mq_timedsend_time64	418
+#define SYS_mq_timedreceive_time64	419
+#define SYS_semtimedop_time64	420
+#define SYS_rt_sigtimedwait_time64	421
+#define SYS_futex_time64	422
+#define SYS_sched_rr_get_interval_time64	423
+#define SYS_pidfd_send_signal	424
+#define SYS_io_uring_setup	425
+#define SYS_io_uring_enter	426
+#define SYS_io_uring_register	427
+#define SYS_open_tree		428
+#define SYS_move_mount		429
+#define SYS_fsopen		430
+#define SYS_fsconfig		431
+#define SYS_fsmount		432
+#define SYS_fspick		433
+#define SYS_pidfd_open		434
+#define SYS_clone3		435
